@@ -1,4 +1,4 @@
-// HighOrderMeshOptimizer - Copyright (C) 2013-2019 UCLouvain-ULiege
+// HighOrderMeshOptimizer - Copyright (C) 2013-2025 UCLouvain-ULiege
 //
 // Permission is hereby granted, free of charge, to any person
 // obtaining a copy of this software and associated documentation
@@ -30,21 +30,22 @@
 #include "BasisFactory.h"
 #include "GFace.h"
 #include "bezierBasis.h"
-
 #include "gmshVertex.h"
 #include "Geo.h"
 #include "MLine.h"
 #include "GModel.h"
-#if defined(HAVE_POST)
-#include "PView.h"
-#endif
-#if defined(HAVE_FLTK)
-#include "FlGui.h"
-#endif
 #include "Options.h"
 #include "AnalyseMeshQuality.h"
 #include "InnerVertexPlacement.h"
 
+#if defined(HAVE_POST)
+#include "PView.h"
+#endif
+
+#if defined(HAVE_FLTK)
+#include "FlGui.h"
+#endif
+
 namespace {
   void draw3DFrame(SPoint3 &p, SVector3 &t, SVector3 &n, SVector3 &w,
                    double unitDimension, GFace *gFace)
@@ -97,7 +98,7 @@ namespace {
   {
     int N = 40;
 
-    MVertex *previous = NULL;
+    MVertex *previous = nullptr;
 
     for(int i = 0; i < N + 1; ++i) {
       const double u = (double)i / N * 2 - 1;
@@ -162,38 +163,59 @@ namespace {
 
 namespace BoundaryLayerCurver {
   namespace InnerVertPlacementMatrices {
-    fullMatrix<double> *_triangle[10] = {NULL, NULL, NULL, NULL, NULL,
-                                         NULL, NULL, NULL, NULL, NULL};
-    fullMatrix<double> *_quadrangle[10] = {NULL, NULL, NULL, NULL, NULL,
-                                           NULL, NULL, NULL, NULL, NULL};
-    fullMatrix<double> *_linearTriangle0[10] = {NULL, NULL, NULL, NULL, NULL,
-                                                NULL, NULL, NULL, NULL, NULL};
-    fullMatrix<double> *_linearTriangle2[10] = {NULL, NULL, NULL, NULL, NULL,
-                                                NULL, NULL, NULL, NULL, NULL};
-    fullMatrix<double> *_linearQuadrangle[10] = {NULL, NULL, NULL, NULL, NULL,
-                                                 NULL, NULL, NULL, NULL, NULL};
-    fullMatrix<double> *_hexahedron[10] = {NULL, NULL, NULL, NULL, NULL,
-                                           NULL, NULL, NULL, NULL, NULL};
+    fullMatrix<double> *_triangle[10] = {nullptr, nullptr, nullptr, nullptr,
+                                         nullptr, nullptr, nullptr, nullptr,
+                                         nullptr, nullptr};
+    fullMatrix<double> *_quadrangle[10] = {nullptr, nullptr, nullptr, nullptr,
+                                           nullptr, nullptr, nullptr, nullptr,
+                                           nullptr, nullptr};
+    fullMatrix<double> *_linearTriangle0[10] = {
+      nullptr, nullptr, nullptr, nullptr, nullptr,
+      nullptr, nullptr, nullptr, nullptr, nullptr};
+    fullMatrix<double> *_linearTriangle2[10] = {
+      nullptr, nullptr, nullptr, nullptr, nullptr,
+      nullptr, nullptr, nullptr, nullptr, nullptr};
+    fullMatrix<double> *_linearQuadrangle[10] = {
+      nullptr, nullptr, nullptr, nullptr, nullptr,
+      nullptr, nullptr, nullptr, nullptr, nullptr};
+    fullMatrix<double> *_hexahedron[10] = {nullptr, nullptr, nullptr, nullptr,
+                                           nullptr, nullptr, nullptr, nullptr,
+                                           nullptr, nullptr};
     fullMatrix<double> *_linearHexahedron[3][10] = {
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL}};
-    fullMatrix<double> *_prism[10] = {NULL, NULL, NULL, NULL, NULL,
-                                      NULL, NULL, NULL, NULL, NULL};
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr},
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr},
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr}};
+    fullMatrix<double> *_prism[10] = {nullptr, nullptr, nullptr, nullptr,
+                                      nullptr, nullptr, nullptr, nullptr,
+                                      nullptr, nullptr};
     fullMatrix<double> *_linearPrism[4][10] = {
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL}};
-    fullMatrix<double> *_tetrahedron[10] = {NULL, NULL, NULL, NULL, NULL,
-                                            NULL, NULL, NULL, NULL, NULL};
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr},
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr},
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr},
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr}};
+    fullMatrix<double> *_tetrahedron[10] = {nullptr, nullptr, nullptr, nullptr,
+                                            nullptr, nullptr, nullptr, nullptr,
+                                            nullptr, nullptr};
     fullMatrix<double> *_linearTet[6][10] = {
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
-      {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL}};
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr},
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr},
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr},
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr},
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr},
+      {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+       nullptr, nullptr}};
 
     const fullMatrix<double> *triangle(int order, bool linear, int edge)
     {
@@ -220,6 +242,7 @@ namespace BoundaryLayerCurver {
         }
         return _linearTriangle2[order];
       }
+      return new fullMatrix<double>();
     }
 
     const fullMatrix<double> *quadrangle(int order, bool linear)
@@ -437,9 +460,9 @@ namespace BoundaryLayerCurver {
     std::map<MEdge, int, MEdgeLessThan> edge2element;
     for(std::size_t i = 0; i < bndEl2column.size(); ++i) {
       MElement *el = bndEl2column[i].first;
-      for(std::size_t j = 0; j < el->getNumEdges(); ++j) {
+      for(int j = 0; j < el->getNumEdges(); ++j) {
         MEdge e = el->getEdge(j);
-        std::map<MEdge, int, MEdgeLessThan>::iterator it = edge2element.find(e);
+        auto it = edge2element.find(e);
         if(it != edge2element.end()) {
           adjacencies.push_back(std::make_pair(i, it->second));
           // This is for debug purpose, we expect that two elements at most
@@ -457,13 +480,13 @@ namespace BoundaryLayerCurver {
   {
     // NB: f1 == f2 will return true for "twisted" quad (having same vertices
     // but the quads are different)
-    int nVertices = f1.getNumVertices();
+    size_t nVertices = f1.getNumVertices();
     if(f2.getNumVertices() != nVertices) return false;
 
     MVertex *v = f1.getVertex(0);
 
     // Find the vertex in f2
-    int k = 0;
+    size_t k = 0;
     while(k < nVertices && f2.getVertex(k) != v) ++k;
     if(k == nVertices) return false;
 
@@ -478,7 +501,7 @@ namespace BoundaryLayerCurver {
       inc = -1;
     if(inc == 0) return false;
 
-    for(int i = 2; i < nVertices; ++i) {
+    for(size_t i = 2; i < nVertices; ++i) {
       if(f1.getVertex(i) != f2.getVertex((k + nVertices + inc * i) % nVertices))
         return false;
     }
@@ -502,7 +525,7 @@ namespace BoundaryLayerCurver {
 
   bool faceContainsVertex(const MFace &f, const MVertex *v)
   {
-    for(int i = 0; i < f.getNumVertices(); ++i) {
+    for(size_t i = 0; i < f.getNumVertices(); ++i) {
       if(f.getVertex(i) == v) return true;
     }
     return false;
@@ -514,7 +537,7 @@ namespace BoundaryLayerCurver {
     MVertex *v1 = e.getMaxVertex();
     bool v0In = false;
     bool v1In = false;
-    for(int i = 0; i < f.getNumVertices(); ++i) {
+    for(size_t i = 0; i < f.getNumVertices(); ++i) {
       if(f.getVertex(i) == v0) v0In = true;
       if(f.getVertex(i) == v1) v1In = true;
     }
@@ -526,7 +549,7 @@ namespace BoundaryLayerCurver {
   {
     int numVertexPerLayer = c1.first->getNumPrimaryVertices();
     std::size_t numLayers = c1.second.size();
-    stack.assign(numVertexPerLayer * numLayers, NULL);
+    stack.assign(numVertexPerLayer * numLayers, nullptr);
 
     int k = 0;
     for(int i = 0; i < numVertexPerLayer; ++i) {
@@ -569,7 +592,7 @@ namespace BoundaryLayerCurver {
       // If there remains NULL values, it is because the vertex is the same
       // on bottom face and top face.
       for(int l = k; l < k + numVertexPerLayer; ++l) {
-        if(stack[l] == NULL) stack[l] = stack[l - numVertexPerLayer];
+        if(stack[l] == nullptr) stack[l] = stack[l - numVertexPerLayer];
       }
 
       k += numVertexPerLayer;
@@ -648,7 +671,7 @@ namespace BoundaryLayerCurver {
 
     // Compute interface
     interface.clear();
-    for(int i = 0; i < stackElements.size() - 1; ++i) {
+    for(size_t i = 0; i < stackElements.size() - 1; ++i) {
       MVertex *v0 = interfacePrimaryVertices[2 * i + 0];
       MVertex *v1 = interfacePrimaryVertices[2 * i + 1];
       MVertex *v2 = interfacePrimaryVertices[2 * i + 3];
@@ -658,10 +681,10 @@ namespace BoundaryLayerCurver {
       }
       if(v2 == v1) {
         v2 = v3;
-        v3 = NULL;
+        v3 = nullptr;
       }
       else if(v3 == v0) {
-        v3 = NULL;
+        v3 = nullptr;
       }
       interface.push_back(
         stackElements[i]->getHighOrderFace(MFace(v0, v1, v2, v3)));
@@ -756,7 +779,7 @@ namespace BoundaryLayerCurver {
                          const MEdgeN &baseEdge,
                          const Parameters3DCurve &parameters, int nbPoints,
                          const IntPt *points, fullMatrix<double> &xyz,
-                         int triDirection = 0, const GFace *gFace = NULL)
+                         int triDirection = 0, const GFace *gFace = nullptr)
   {
     //  static int ITER = 0;
     //  ++ITER;
@@ -876,7 +899,7 @@ namespace BoundaryLayerCurver {
     fullMatrix<double> newxyz(orderCurve + 1, 3);
     data->invA.mult(xyz, newxyz);
 
-    for(int i = 2; i < topEdge.getNumVertices(); ++i) {
+    for(size_t i = 2; i < topEdge.getNumVertices(); ++i) {
       MVertex *v = topEdge.getVertex(i);
       v->x() = newxyz(i, 0);
       v->y() = newxyz(i, 1);
@@ -955,7 +978,7 @@ namespace BoundaryLayerCurver {
       case 1: factor = (v->y() - vbot->y()) / dY; break;
       case 2: factor = (v->z() - vbot->z()) / dZ; break;
       }
-      for(int j = 2; j < e.getNumVertices(); ++j) {
+      for(size_t j = 2; j < e.getNumVertices(); ++j) {
         MVertex *vbot = baseEdge.getVertex(j);
         MVertex *vtop = topEdge.getVertex(j);
         MVertex *v = e.getVertex(j);
@@ -970,7 +993,7 @@ namespace BoundaryLayerCurver {
   {
     for(std::size_t i = 0; i < column.size(); ++i) {
       MFaceN &f = column[i];
-      const fullMatrix<double> *placement = NULL;
+      const fullMatrix<double> *placement = nullptr;
       if(f.isTriangular()) {
         // TODO Determine if edge 0 or 2
       }
@@ -1106,7 +1129,7 @@ namespace BoundaryLayerCurver {
     fullMatrix<double> newxyz(data->invA.size1(), 3);
     data->invA.mult(xyz, newxyz);
 
-    for(int i = nVerticesBoundary; i < topFace.getNumVertices(); ++i) {
+    for(size_t i = nVerticesBoundary; i < topFace.getNumVertices(); ++i) {
       MVertex *v = topFace.getVertex(i);
       v->x() = newxyz(i, 0);
       v->y() = newxyz(i, 1);
@@ -1145,7 +1168,7 @@ namespace BoundaryLayerCurver {
       case 1: factor = (v->y() - vbot->y()) / dY; break;
       case 2: factor = (v->z() - vbot->z()) / dZ; break;
       }
-      for(int j = f.getNumVerticesOnBoundary(); j < f.getNumVertices(); ++j) {
+      for(size_t j = f.getNumVerticesOnBoundary(); j < f.getNumVertices(); ++j) {
         MVertex *vbot = baseFace.getVertex(j);
         MVertex *vtop = topFace.getVertex(j);
         MVertex *v = f.getVertex(j);
@@ -1160,7 +1183,7 @@ namespace BoundaryLayerCurver {
                                const fullMatrix<double> &placement)
   {
     int start = el->getNumVertices() - el->getNumVolumeVertices();
-    for(int i = start; i < el->getNumVertices(); ++i) {
+    for(size_t i = start; i < el->getNumVertices(); ++i) {
       MVertex *v = el->getVertex(i);
       v->x() = 0;
       v->y() = 0;
@@ -1181,7 +1204,7 @@ namespace BoundaryLayerCurver {
     // TODO: reposition last elements
     for(std::size_t i = 0; i < column.size() - 1; ++i) {
       MElement *el = column[i];
-      const fullMatrix<double> *placement = NULL;
+      const fullMatrix<double> *placement = nullptr;
       const int order = el->getPolynomialOrder();
       int nFace, nOtherFace, sign, rot;
       switch(el->getType()) {
@@ -1247,7 +1270,7 @@ void curve3DBoundaryLayer(VecPairMElemVecMElem &bndEl2column,
   BoundaryLayerCurver::curveColumns(bndEl2column, boundary);
 
   //  Msg::Info("size %d", bndEl2column.size());
-  for(int i = 0; i < bndEl2column.size(); ++i) {
+  for(size_t i = 0; i < bndEl2column.size(); ++i) {
     bndEl2column[i].first->setVisibility(1);
     //    Msg::Info("el %d, size %d", bndEl2column[i].first->getNum(),
     //    bndEl2column[i].second.size());
