@@ -1,21 +1,14 @@
-//
-//  PostProcessingViewController.h
-//  Onelab
-//
-//  Created by Maxime Graulich on 22/08/13.
-//  Copyright (c) 2013 Maxime Graulich. All rights reserved.
-//
-
 #import <UIKit/UIKit.h>
 
 #include <gmsh/PView.h>
 #include <gmsh/PViewData.h>
 #include <gmsh/PViewOptions.h>
 
-@interface PostProcessingViewController : UIViewController <UIPickerViewDataSource, UIPickerViewDelegate, UITextFieldDelegate>
-{
+@interface PostProcessingViewController
+  : UIViewController <UIPickerViewDataSource, UIPickerViewDelegate,
+                      UITextFieldDelegate> {
 @private
-    PView *_pview;
+  PView *_pview;
 }
 
 @property (weak, nonatomic) IBOutlet UILabel *Name;
@@ -26,6 +19,6 @@
 
 - (IBAction)stepperValueChanged:(UIStepper *)sender;
 
-- (void)setPView:(PView*)p;
+- (void)setPView:(PView *)p;
 
 @end
