@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2022 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -32,6 +32,8 @@ class Msg {
 private:
   // current cpu number and total number of cpus
   static int _commRank, _commSize;
+  // did Gmsh initialize MPI?
+  static bool _mpiInit;
   // verbosity level (0: silent except fatal errors, 1: +errors, 2: +warnings,
   // 3: +direct, 4: +info, 5 (=normal): +statusbar, 99: debug)
   static int _verbosity;
@@ -75,7 +77,7 @@ public:
   Msg() {}
   static void Initialize(int argc, char **argv);
   static void Finalize();
-  static void Exit(int level);
+  static void Exit(int level, bool forceLevel = false);
   static int GetCommRank();
   static int GetCommSize();
   static void SetCommRank(int val);
@@ -88,7 +90,8 @@ public:
   static int GetMaxThreads();
   static int GetThreadNum();
   static void SetVerbosity(int val);
-  static void SetLogFile(const std::string &name);
+  static void SetLogFileName(const std::string &name);
+  static std::string GetLogFileName();
   static int GetVerbosity();
   static std::string GetLaunchDate();
   static std::string GetCommandLineFull();
