@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2022 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -46,6 +46,8 @@ std::string opt_general_tmp_filename(OPT_ARGS_STR);
 std::string opt_general_error_filename(OPT_ARGS_STR);
 std::string opt_general_session_filename(OPT_ARGS_STR);
 std::string opt_general_options_filename(OPT_ARGS_STR);
+std::string opt_general_log_filename(OPT_ARGS_STR);
+std::string opt_general_number_format(OPT_ARGS_STR);
 std::string opt_general_recent_file0(OPT_ARGS_STR);
 std::string opt_general_recent_file1(OPT_ARGS_STR);
 std::string opt_general_recent_file2(OPT_ARGS_STR);
@@ -68,6 +70,16 @@ std::string opt_geometry_double_clicked_curve_command(OPT_ARGS_STR);
 std::string opt_geometry_double_clicked_surface_command(OPT_ARGS_STR);
 std::string opt_geometry_double_clicked_volume_command(OPT_ARGS_STR);
 std::string opt_geometry_occ_target_unit(OPT_ARGS_STR);
+std::string opt_geometry_occ_step_description(OPT_ARGS_STR);
+std::string opt_geometry_occ_step_implementation_level(OPT_ARGS_STR);
+std::string opt_geometry_occ_step_model_name(OPT_ARGS_STR);
+std::string opt_geometry_occ_step_time_stamp(OPT_ARGS_STR);
+std::string opt_geometry_occ_step_author(OPT_ARGS_STR);
+std::string opt_geometry_occ_step_organization(OPT_ARGS_STR);
+std::string opt_geometry_occ_step_preprocessor_version(OPT_ARGS_STR);
+std::string opt_geometry_occ_step_originating_system(OPT_ARGS_STR);
+std::string opt_geometry_occ_step_authorization(OPT_ARGS_STR);
+std::string opt_geometry_occ_step_schema_identifier(OPT_ARGS_STR);
 std::string opt_geometry_pipe_default_trihedron(OPT_ARGS_STR);
 std::string opt_solver_socket_name(OPT_ARGS_STR);
 std::string opt_solver_name(OPT_ARGS_STR);
@@ -118,7 +130,7 @@ std::string opt_solver_octave_interpreter(OPT_ARGS_STR);
 std::string opt_solver_python_interpreter(OPT_ARGS_STR);
 std::string opt_post_double_clicked_graph_point_command(OPT_ARGS_STR);
 std::string opt_view_name(OPT_ARGS_STR);
-std::string opt_view_format(OPT_ARGS_STR);
+std::string opt_view_number_format(OPT_ARGS_STR);
 std::string opt_view_filename(OPT_ARGS_STR);
 std::string opt_view_double_clicked_command(OPT_ARGS_STR);
 std::string opt_view_group(OPT_ARGS_STR);
@@ -295,9 +307,7 @@ double opt_general_zoom_factor(OPT_ARGS_NUM);
 double opt_general_expert_mode(OPT_ARGS_NUM);
 double opt_general_stereo_mode(OPT_ARGS_NUM);
 double opt_general_camera_mode(OPT_ARGS_NUM);
-#if defined(HAVE_VISUDEV)
 double opt_general_heavy_visualization(OPT_ARGS_NUM);
-#endif
 double opt_general_eye_sep_ratio(OPT_ARGS_NUM);
 double opt_general_focallength_ratio(OPT_ARGS_NUM);
 double opt_general_camera_aperture(OPT_ARGS_NUM);
@@ -374,6 +384,8 @@ double opt_geometry_offset1(OPT_ARGS_NUM);
 double opt_geometry_offset2(OPT_ARGS_NUM);
 double opt_geometry_auto_coherence(OPT_ARGS_NUM);
 double opt_geometry_oriented_physicals(OPT_ARGS_NUM);
+double opt_geometry_first_entity_tag(OPT_ARGS_NUM);
+double opt_geometry_first_physical_tag(OPT_ARGS_NUM);
 double opt_geometry_highlight_orphans(OPT_ARGS_NUM);
 double opt_geometry_tolerance(OPT_ARGS_NUM);
 double opt_geometry_tolerance_boolean(OPT_ARGS_NUM);
@@ -396,21 +408,26 @@ double opt_geometry_curve_width(OPT_ARGS_NUM);
 double opt_geometry_curve_sel_width(OPT_ARGS_NUM);
 double opt_geometry_curve_type(OPT_ARGS_NUM);
 double opt_geometry_surface_type(OPT_ARGS_NUM);
+double opt_geometry_volume_type(OPT_ARGS_NUM);
 double opt_geometry_light(OPT_ARGS_NUM);
 double opt_geometry_light_two_side(OPT_ARGS_NUM);
 double opt_geometry_occ_auto_embed(OPT_ARGS_NUM);
-double opt_geometry_occ_safe_unbind(OPT_ARGS_NUM);
+double opt_geometry_occ_fast_unbind(OPT_ARGS_NUM);
 double opt_geometry_occ_auto_fix(OPT_ARGS_NUM);
 double opt_geometry_occ_bounds_use_stl(OPT_ARGS_NUM);
+double opt_geometry_occ_brep_format_version(OPT_ARGS_NUM);
 double opt_geometry_occ_disable_stl(OPT_ARGS_NUM);
 double opt_geometry_occ_fix_degenerated(OPT_ARGS_NUM);
 double opt_geometry_occ_fix_small_edges(OPT_ARGS_NUM);
 double opt_geometry_occ_fix_small_faces(OPT_ARGS_NUM);
 double opt_geometry_occ_sew_faces(OPT_ARGS_NUM);
 double opt_geometry_occ_make_solids(OPT_ARGS_NUM);
-double opt_geometry_occ_union_unify(OPT_ARGS_NUM);
 double opt_geometry_occ_parallel(OPT_ARGS_NUM);
+double opt_geometry_occ_boolean_check_inverted(OPT_ARGS_NUM);
+double opt_geometry_occ_boolean_glue(OPT_ARGS_NUM);
+double opt_geometry_occ_boolean_non_destructive(OPT_ARGS_NUM);
 double opt_geometry_occ_boolean_preserve_numbering(OPT_ARGS_NUM);
+double opt_geometry_occ_boolean_simplify(OPT_ARGS_NUM);
 double opt_geometry_occ_scaling(OPT_ARGS_NUM);
 double opt_geometry_occ_export_only_visible(OPT_ARGS_NUM);
 double opt_geometry_occ_import_labels(OPT_ARGS_NUM);
@@ -438,6 +455,7 @@ double opt_mesh_label_sampling(OPT_ARGS_NUM);
 double opt_mesh_optimize(OPT_ARGS_NUM);
 double opt_mesh_optimize_threshold(OPT_ARGS_NUM);
 double opt_mesh_optimize_netgen(OPT_ARGS_NUM);
+double opt_mesh_optimize_pyramids(OPT_ARGS_NUM);
 double opt_mesh_refine_steps(OPT_ARGS_NUM);
 double opt_mesh_normals(OPT_ARGS_NUM);
 double opt_mesh_num_sub_edges(OPT_ARGS_NUM);
@@ -455,6 +473,7 @@ double opt_mesh_lc_from_points(OPT_ARGS_NUM);
 double opt_mesh_lc_from_parametric_points(OPT_ARGS_NUM);
 double opt_mesh_lc_extend_from_boundary(OPT_ARGS_NUM);
 double opt_mesh_lc_integration_precision(OPT_ARGS_NUM);
+double opt_mesh_check_surface_normal_validity(OPT_ARGS_NUM);
 double opt_mesh_rand_factor(OPT_ARGS_NUM);
 double opt_mesh_rand_factor3d(OPT_ARGS_NUM);
 double opt_mesh_quality_inf(OPT_ARGS_NUM);
@@ -526,7 +545,7 @@ double opt_mesh_binary(OPT_ARGS_NUM);
 double opt_mesh_smooth_cross_field(OPT_ARGS_NUM);
 double opt_mesh_cross_field_closest_point(OPT_ARGS_NUM);
 double opt_mesh_bdf_field_format(OPT_ARGS_NUM);
-double opt_mesh_stl_remove_duplicate_triangles(OPT_ARGS_NUM);
+double opt_mesh_stl_remove_bad_triangles(OPT_ARGS_NUM);
 double opt_mesh_stl_one_solid_per_surface(OPT_ARGS_NUM);
 double opt_mesh_stl_linear_deflection(OPT_ARGS_NUM);
 double opt_mesh_stl_linear_deflection_relative(OPT_ARGS_NUM);
@@ -546,6 +565,7 @@ double opt_mesh_recombine3d_all(OPT_ARGS_NUM);
 double opt_mesh_recombine3d_level(OPT_ARGS_NUM);
 double opt_mesh_recombine3d_conformity(OPT_ARGS_NUM);
 double opt_mesh_flexible_transfinite(OPT_ARGS_NUM);
+double opt_mesh_quasi_transfinite(OPT_ARGS_NUM);
 double opt_mesh_algo_subdivide(OPT_ARGS_NUM);
 double opt_mesh_mesh_only_visible(OPT_ARGS_NUM);
 double opt_mesh_mesh_only_empty(OPT_ARGS_NUM);
@@ -571,6 +591,7 @@ double opt_mesh_ho_max_rho(OPT_ARGS_NUM);
 double opt_mesh_ho_max_angle(OPT_ARGS_NUM);
 double opt_mesh_ho_max_in_angle(OPT_ARGS_NUM);
 double opt_mesh_ho_fix_bnd_nodes(OPT_ARGS_NUM);
+double opt_mesh_ho_skip_quality_check(OPT_ARGS_NUM);
 double opt_mesh_second_order_linear(OPT_ARGS_NUM);
 double opt_mesh_second_order_incomplete(OPT_ARGS_NUM);
 double opt_mesh_cgns_import_order(OPT_ARGS_NUM);
@@ -605,7 +626,10 @@ double opt_mesh_nb_prisms(OPT_ARGS_NUM);
 double opt_mesh_nb_pyramids(OPT_ARGS_NUM);
 double opt_mesh_nb_trihedra(OPT_ARGS_NUM);
 double opt_mesh_cpu_time(OPT_ARGS_NUM);
+double opt_mesh_min_quality(OPT_ARGS_NUM);
+double opt_mesh_avg_quality(OPT_ARGS_NUM);
 double opt_mesh_clip(OPT_ARGS_NUM);
+double opt_mesh_ignore_unknown_sections(OPT_ARGS_NUM);
 double opt_mesh_ignore_periodicity(OPT_ARGS_NUM);
 double opt_mesh_preserve_numbering_msh2(OPT_ARGS_NUM);
 double opt_mesh_max_iter_delaunay_3d(OPT_ARGS_NUM);
@@ -617,6 +641,7 @@ double opt_mesh_tolerance_reference_element(OPT_ARGS_NUM);
 double opt_mesh_renumber(OPT_ARGS_NUM);
 double opt_mesh_unv_strict_format(OPT_ARGS_NUM);
 double opt_mesh_reparam_max_triangles(OPT_ARGS_NUM);
+double opt_mesh_reproducible(OPT_ARGS_NUM);
 double opt_mesh_ignore_parametrization(OPT_ARGS_NUM);
 double opt_mesh_quadqs_sizemap_method(OPT_ARGS_NUM);
 double opt_mesh_quadqs_topo_optim_methods(OPT_ARGS_NUM);
