@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2022 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -485,9 +485,11 @@ Cell *CellComplex::_omitCell(Cell *cell, bool dual)
   std::string domainstr = "";
   int domain = getDomain(cell, domainstr);
 
-  Msg::Debug("Cell complex %d-omit removed %dv, %df, %de, %dn", cell->getDim(),
+  Msg::Debug("Cell complex %d-omit removed %dv, %df, %de, %dn (total %d)",
+             cell->getDim(),
              numCells[3] - getSize(3), numCells[2] - getSize(2),
-             numCells[1] - getSize(1), numCells[0] - getSize(0));
+             numCells[1] - getSize(1), numCells[0] - getSize(0),
+             count);
   Msg::Debug(" - number of %d-cells left in %s: %d", cell->getDim(),
              domainstr.c_str(), getNumCells(cell->getDim(), domain));
 
@@ -996,7 +998,7 @@ int CellComplex::saveComplex(const std::string &filename)
   for(int dim = 0; dim < 4; dim++){
     for(citer cit = firstCell(dim); cit != lastCell(dim); cit++){
       Cell* cell = *cit;
-      fprintf(fp, "%d %d %d %d %lu", cell->getNum(), cell->getType(),
+      fprintf(fp, "%d %d %d %d %zu", cell->getNum(), cell->getType(),
           1, cell->getDomain(), cell->getNumVertices());
       for(std::size_t i = 0; i < cell->getNumVertices(); i++){
     fprintf(fp, " %d", cell->getVertex(i));
