@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2022 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -58,8 +58,8 @@ public:
   virtual void deleteMesh();
 
   // get the start/end vertices of the edge
-  void setBeginVertex(GVertex *gv) { _v0 = gv; gv->addEdge(this); }
-  void setEndVertex(GVertex *gv) { _v1 = gv; gv->addEdge(this); }
+  void setBeginVertex(GVertex *gv) { _v0 = gv; if(gv) gv->addEdge(this); }
+  void setEndVertex(GVertex *gv) { _v1 = gv; if(gv) gv->addEdge(this); }
   virtual GVertex *getBeginVertex() const { return _v0; }
   virtual GVertex *getEndVertex() const { return _v1; }
   void setVertex(GVertex *const f, const int orientation)
@@ -119,7 +119,7 @@ public:
   virtual bool isOrphan();
 
   // get the point for the given parameter location
-  virtual GPoint point(double p) const = 0;
+  virtual GPoint point(double p) const { return GPoint(); }
 
   // true if the edge contains the given parameter
   virtual bool containsParam(double pt) const;
@@ -132,7 +132,7 @@ public:
   }
 
   // get first derivative of edge at the given parameter
-  virtual SVector3 firstDer(double par) const = 0;
+  virtual SVector3 firstDer(double par) const { return SVector3(); }
 
   // get second derivative of edge at the given parameter (default
   // implentation using central differences)
@@ -219,7 +219,7 @@ public:
   virtual bool periodic(int dim) const { return _v0 == _v1; }
 
   // get bounds of parametric coordinate
-  virtual Range<double> parBounds(int i) const = 0;
+  virtual Range<double> parBounds(int i) const { return Range<double>(); }
   virtual Range<double> parBoundsOnFace(GFace *face = nullptr) const
   {
     return parBounds(0);
@@ -259,14 +259,20 @@ public:
     bool reverseMesh;
   } meshAttributes;
 
+  virtual double getMeshSize() const { return meshAttributes.meshSize; }
+  virtual double getMeshSizeFactor() const
+  {
+    return meshAttributes.meshSizeFactor;
+  }
+
   struct {
     mutable GEntity::MeshGenerationStatus status;
   } meshStatistics;
 
   void addLine(MLine *line) { lines.push_back(line); }
-  void addElement(int type, MElement *e);
-  void removeElement(int type, MElement *e);
-  void removeElements(int type);
+  void addElement(MElement *e);
+  void removeElement(MElement *e, bool del=false);
+  void removeElements(bool del=false);
 
   virtual void discretize(double tol, std::vector<SPoint3> &dpts,
                           std::vector<double> &ts);
