@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2022 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -28,8 +28,10 @@
 
 void GEO_Internals::_allocateAll()
 {
-  _maxPointNum = _maxLineNum = _maxLineLoopNum = _maxSurfaceNum = 0;
-  _maxSurfaceLoopNum = _maxVolumeNum = _maxPhysicalNum = 0;
+  int t = CTX::instance()->geom.firstEntityTag;
+  _maxPointNum = _maxLineNum = _maxLineLoopNum = _maxSurfaceNum = t - 1;
+  _maxSurfaceLoopNum = _maxVolumeNum = t - 1;
+  _maxPhysicalNum = CTX::instance()->geom.firstPhysicalTag - 1;
 
   Points = Tree_Create(sizeof(Vertex *), CompareVertex);
   Curves = Tree_Create(sizeof(Curve *), CompareCurve);
@@ -38,7 +40,7 @@ void GEO_Internals::_allocateAll()
   SurfaceLoops = Tree_Create(sizeof(SurfaceLoop *), CompareSurfaceLoop);
   Volumes = Tree_Create(sizeof(Volume *), CompareVolume);
 
-  PhysicalGroups = List_Create(5, 5, sizeof(PhysicalGroup *));
+  PhysicalGroups = Tree_Create(sizeof(PhysicalGroup *), ComparePhysicalGroup);
   DelPhysicalGroups = List_Create(5, 5, sizeof(PhysicalGroup *));
 
   DelPoints = Tree_Create(sizeof(Vertex *), CompareVertex);
@@ -51,8 +53,10 @@ void GEO_Internals::_allocateAll()
 
 void GEO_Internals::_freeAll()
 {
-  _maxPointNum = _maxLineNum = _maxLineLoopNum = _maxSurfaceNum = 0;
-  _maxSurfaceLoopNum = _maxVolumeNum = _maxPhysicalNum = 0;
+  int t = CTX::instance()->geom.firstEntityTag;
+  _maxPointNum = _maxLineNum = _maxLineLoopNum = _maxSurfaceNum = t - 1;
+  _maxSurfaceLoopNum = _maxVolumeNum = t - 1;
+  _maxPhysicalNum = CTX::instance()->geom.firstPhysicalTag - 1;
 
   Tree_Action(Points, FreeVertex);
   Tree_Delete(Points);
@@ -76,8 +80,8 @@ void GEO_Internals::_freeAll()
   Tree_Action(DelVolumes, FreeVolume);
   Tree_Delete(DelVolumes);
 
-  List_Action(PhysicalGroups, FreePhysicalGroup);
-  List_Delete(PhysicalGroups);
+  Tree_Action(PhysicalGroups, FreePhysicalGroup);
+  Tree_Delete(PhysicalGroups);
   List_Action(DelPhysicalGroups, FreePhysicalGroup);
   List_Delete(DelPhysicalGroups);
 
@@ -87,12 +91,23 @@ void GEO_Internals::_freeAll()
 void GEO_Internals::setMaxTag(int dim, int val)
 {
   switch(dim) {
+#if 0
+  // this is "right" (so that we always obey Geometry.FirstEntityTag) but breaks
+  // backward compatibility
+  case 0: _maxPointNum = std::max(_maxPointNum, val); break;
+  case 1: _maxLineNum = std::max(_maxLineNum, val); break;
+  case -1: _maxLineLoopNum = std::max(_maxLineLoopNum, val); break;
+  case 2: _maxSurfaceNum = std::max(_maxSurfaceNum, val); break;
+  case -2: _maxSurfaceLoopNum = std::max(_maxSurfaceLoopNum, val); break;
+  case 3: _maxVolumeNum = std::max(_maxVolumeNum, val); break;
+#else
   case 0: _maxPointNum = val; break;
   case 1: _maxLineNum = val; break;
   case -1: _maxLineLoopNum = val; break;
   case 2: _maxSurfaceNum = val; break;
   case -2: _maxSurfaceLoopNum = val; break;
   case 3: _maxVolumeNum = val; break;
+#endif
   }
 }
 
@@ -555,7 +570,7 @@ bool GEO_Internals::addCurveLoops(const std::vector<int> &curveTags,
 
   for(std::size_t i = 0; i < vs.size(); i++) {
     if(vs[i].size() < 2 || vs[i][0] != vs[i][vs[i].size() - 1]) {
-      Msg::Warning("Skipping invalid loop with %lu points", vs[i].size());
+      Msg::Warning("Skipping invalid loop with %zu points", vs[i].size());
       continue;
     }
     else {
@@ -991,9 +1006,9 @@ bool GEO_Internals::remove(const std::vector<std::pair<int, int> > &dimTags,
 
 void GEO_Internals::resetPhysicalGroups()
 {
-  List_Action(PhysicalGroups, FreePhysicalGroup);
+  Tree_Action(PhysicalGroups, FreePhysicalGroup);
+  Tree_Reset(PhysicalGroups);
   List_Action(DelPhysicalGroups, FreePhysicalGroup);
-  List_Reset(PhysicalGroups);
   _changed = true;
 }
 
@@ -1027,6 +1042,11 @@ bool GEO_Internals::modifyPhysicalGroup(int dim, int tag, int op,
     Msg::Error("Physical %s %d already exists", str.c_str(), tag);
     return false;
   }
+  else if(!p && op == 2) {
+    // we call this in gmsh::model::removePhysicalGroup(), so it's not an error
+    // if the group does not exist
+    return true;
+  }
   else if(!p && op > 0) {
     Msg::Error("Physical %s %d does not exist", str.c_str(), tag);
     return false;
@@ -1039,7 +1059,7 @@ bool GEO_Internals::modifyPhysicalGroup(int dim, int tag, int op,
     }
     p = CreatePhysicalGroup(tag, type, tmp);
     List_Delete(tmp);
-    List_Add(PhysicalGroups, &p);
+    Tree_Add(PhysicalGroups, &p);
   }
   else if(op == 1) {
     for(std::size_t i = 0; i < tags.size(); i++) {
@@ -1354,6 +1374,14 @@ void GEO_Internals::setMeshSizeFromBoundary(int dim, int tag, int val)
   _changed = true;
 }
 
+bool sortEntities(const std::pair<int, int> &a,
+                  const std::pair<int, int> &b)
+{
+  if(a.first != b.first)
+    return a.first > b.first;
+  return a.second < b.second;
+}
+
 void GEO_Internals::synchronize(GModel *model, bool resetMeshAttributes)
 {
   Msg::Debug("Syncing GEO_Internals with GModel");
@@ -1401,10 +1429,12 @@ void GEO_Internals::synchronize(GModel *model, bool resetMeshAttributes)
         toRemove.push_back(std::make_pair(3, gr->tag()));
     }
   }
-  Msg::Debug("Sync is removing %d model entities", toRemove.size());
+  std::sort(toRemove.begin(), toRemove.end(), sortEntities);
+  Msg::Debug("Sync will try to remove %d model entities", toRemove.size());
+
   std::vector<GEntity*> removed;
   model->remove(toRemove, removed);
-  Msg::Debug("Destroying %lu entities in model", removed.size());
+  Msg::Debug("Destroying %zu model entities during first pass", removed.size());
   for(std::size_t i = 0; i < removed.size(); i++) delete removed[i];
 
   if(Tree_Nbr(Points)) {
@@ -1499,33 +1529,69 @@ void GEO_Internals::synchronize(GModel *model, bool resetMeshAttributes)
     List_Delete(volumes);
   }
 
+  // In the first removal pass, entities which were on the boundary of a
+  // higher-dimensional entity that is not removed, will not have been removed
+  // due to the dependency that still existed in the topological GModel. After
+  // recreation of the topology of these higher dimensional entities
+  // (cf. resetNativePtr() above), we can try to re-remove the lower dimension
+  // entities
+  removed.clear();
+  model->remove(toRemove, removed);
+  Msg::Debug("Destroying %zu model entities during second pass", removed.size());
+  for(std::size_t i = 0; i < removed.size(); i++) delete removed[i];
+
   // delete all physical groups before sync only if there is no mesh (if there
   // is a mesh, it could have been loaded from a file with physical groups - we
-  // don't want to remove those)
-  if(!model->getNumMeshElements()) model->removePhysicalGroups();
+  // don't want to remove those) and we have physical groups in the built-in
+  // kernel
+  if(!model->getNumMeshElements() && Tree_Nbr(PhysicalGroups))
+    model->removePhysicalGroups();
   // we might want to store physical groups directly in GModel; but I guess this
   // is OK for now:
-  for(int i = 0; i < List_Nbr(PhysicalGroups); i++) {
-    PhysicalGroup *p;
-    List_Read(PhysicalGroups, i, &p);
-    for(int j = 0; j < List_Nbr(p->Entities); j++) {
-      int num;
-      List_Read(p->Entities, j, &num);
-      GEntity *ge = nullptr;
-      int tag = CTX::instance()->geom.orientedPhysicals ? abs(num) : num;
-      switch(p->Typ) {
-      case MSH_PHYSICAL_POINT: ge = model->getVertexByTag(tag); break;
-      case MSH_PHYSICAL_LINE: ge = model->getEdgeByTag(tag); break;
-      case MSH_PHYSICAL_SURFACE: ge = model->getFaceByTag(tag); break;
-      case MSH_PHYSICAL_VOLUME: ge = model->getRegionByTag(tag); break;
+  if(Tree_Nbr(PhysicalGroups)) {
+    List_T *groups = Tree2List(PhysicalGroups);
+    for(int i = 0; i < List_Nbr(groups); i++) {
+      PhysicalGroup *p;
+      List_Read(groups, i, &p);
+      for(int j = 0; j < List_Nbr(p->Entities); j++) {
+        int num;
+        List_Read(p->Entities, j, &num);
+        GEntity *ge = nullptr;
+        const char *name = "";
+        int tag = CTX::instance()->geom.orientedPhysicals ? abs(num) : num;
+        switch(p->Typ) {
+        case MSH_PHYSICAL_POINT:
+          ge = model->getVertexByTag(tag);
+          name = "point";
+          break;
+        case MSH_PHYSICAL_LINE:
+          ge = model->getEdgeByTag(tag);
+          name = "curve";
+          break;
+        case MSH_PHYSICAL_SURFACE:
+          ge = model->getFaceByTag(tag);
+          name = "surface";
+          break;
+        case MSH_PHYSICAL_VOLUME:
+          ge = model->getRegionByTag(tag);
+          name = "volume";
+          break;
+        }
+        if(ge) {
+          int pnum = CTX::instance()->geom.orientedPhysicals ?
+            (gmsh_sign(num) * p->Num) : p->Num;
+          if(std::find(ge->physicals.begin(), ge->physicals.end(), pnum) ==
+             ge->physicals.end()) {
+            ge->physicals.push_back(pnum);
+          }
+        }
+        else {
+          Msg::Warning("Skipping unknown %s %d in physical %s %d",
+                       name, tag, name, p->Num);
+        }
       }
-      int pnum = CTX::instance()->geom.orientedPhysicals ?
-                   (gmsh_sign(num) * p->Num) :
-                   p->Num;
-      if(ge && std::find(ge->physicals.begin(), ge->physicals.end(), pnum) ==
-                 ge->physicals.end())
-        ge->physicals.push_back(pnum);
     }
+    List_Delete(groups);
   }
 
   // we might want to store mesh compounds directly in GModel; but this is OK
@@ -1537,13 +1603,21 @@ void GEO_Internals::synchronize(GModel *model, bool resetMeshAttributes)
     for(std::size_t i = 0; i < compound.size(); i++) {
       int tag = compound[i];
       GEntity *ent = nullptr;
+      const char *name = "";
       switch(dim) {
-      case 1: ent = model->getEdgeByTag(tag); break;
-      case 2: ent = model->getFaceByTag(tag); break;
-      case 3: ent = model->getRegionByTag(tag); break;
-      default: Msg::Error("Compound mesh constraint with dimension %d", dim);
+      case 1: ent = model->getEdgeByTag(tag); name = "curve"; break;
+      case 2: ent = model->getFaceByTag(tag); name = "surface"; break;
+      case 3: ent = model->getRegionByTag(tag); name = "volume"; break;
+      default:
+        Msg::Error("Compound mesh constraint with dimension %d", dim);
+        continue;
+      }
+      if(ent) {
+        ents.push_back(ent);
+      }
+      else {
+        Msg::Warning("Skipping unknown %d %d in compound", name, tag);
       }
-      if(ent) ents.push_back(ent);
     }
     for(std::size_t i = 0; i < ents.size(); i++) { ents[i]->compound = ents; }
   }
@@ -1637,6 +1711,7 @@ public:
   }
   void operator()(std::pair<std::string, FieldOption *> it)
   {
+    if(it.second->isDeprecated()) return;
     std::string v;
     it.second->getTextRepresentation(v);
     fprintf(geo, "Field[%i].%s = %s;\n", field->id, it.first.c_str(),
@@ -1652,6 +1727,7 @@ public:
   writeFieldGEO(FILE *fp) { geo = fp ? fp : stdout; }
   void operator()(std::pair<const int, Field *> it)
   {
+    if(it.second->isDeprecated()) return;
     fprintf(geo, "Field[%i] = %s;\n", it.first, it.second->getName());
     std::for_each(it.second->options.begin(), it.second->options.end(),
                   writeFieldOptionGEO(geo, it.second));
@@ -1755,6 +1831,91 @@ int GModel::writeGEO(const std::string &name, bool printLabels,
     return 0;
   }
 
+  bool occ = true, geo = true;
+  for(auto it = firstVertex(); it != lastVertex(); it++) {
+    if((*it)->getNativeType() != GEntity::OpenCascadeModel) occ = false;
+    if((*it)->getNativeType() != GEntity::GmshModel) geo = false;
+  }
+
+  // if we only have OpenCASCADE data, serialize it to .xao instead of doing an
+  // incomplete .geo export (this is a typical source of confusion for new
+  // users); to force unrolled debug .geo output with OCC geometries, simply add
+  // a dummy built-in point
+  if(occ) {
+    if(writeOCCXAO(name + ".xao")) {
+      fprintf(fp, "Merge \"%s\";\n", (name + ".xao").c_str());
+    }
+    else
+      Msg::Error("Could not write '%s'", (name + ".xao").c_str());
+  }
+  else {
+    if(!geo)
+      Msg::Warning("Exporting non 'built-in' CAD kernel entities in .geo "
+                   "format is for debugging only - most entities are not "
+                   "supported");
+
+    std::map<double, std::string> meshSizeParameters;
+    int cpt = 0;
+    for(auto it = firstVertex(); it != lastVertex(); it++) {
+      double val = (*it)->prescribedMeshSizeAtVertex();
+      if(meshSizeParameters.find(val) == meshSizeParameters.end()) {
+        std::ostringstream paramName;
+        paramName << "cl__" << ++cpt;
+        fprintf(fp, "%s = %.16g;\n", paramName.str().c_str(), val);
+        meshSizeParameters.insert(std::make_pair(val, paramName.str()));
+      }
+    }
+    for(auto it = firstVertex(); it != lastVertex(); it++) {
+      double val = (*it)->prescribedMeshSizeAtVertex();
+      if(!onlyPhysicals || !skipVertex(*it))
+        (*it)->writeGEO(fp, meshSizeParameters[val]);
+    }
+    for(auto it = firstEdge(); it != lastEdge(); it++) {
+      if(!onlyPhysicals || !skipEdge(*it)) (*it)->writeGEO(fp);
+    }
+    for(auto it = firstFace(); it != lastFace(); it++) {
+      if(!onlyPhysicals || !skipFace(*it)) (*it)->writeGEO(fp);
+    }
+    for(auto it = firstRegion(); it != lastRegion(); it++) {
+      if(!onlyPhysicals || !skipRegion(*it)) (*it)->writeGEO(fp);
+    }
+    std::map<int, std::string> labels;
+#if defined(HAVE_PARSER)
+    // get "old-style" labels from parser
+    for(auto it = gmsh_yysymbols.begin(); it != gmsh_yysymbols.end(); ++it)
+      for(std::size_t i = 0; i < it->second.value.size(); i++)
+        labels[(int)it->second.value[i]] = it->first;
+#endif
+    std::map<int, std::vector<GEntity *> > groups[4];
+    getPhysicalGroups(groups);
+    for(int i = 0; i < 4; i++)
+      std::for_each(groups[i].begin(), groups[i].end(),
+                    writePhysicalGroupGEO(fp, i, printLabels, labels,
+                                          _physicalNames));
+  }
+
+#if defined(HAVE_MESH)
+  std::for_each(getFields()->begin(), getFields()->end(), writeFieldGEO(fp));
+  if(getFields()->getBackgroundField() > 0)
+    fprintf(fp, "Background Field = %i;\n", getFields()->getBackgroundField());
+#endif
+
+  fclose(fp);
+  return 1;
+}
+
+int GModel::writePY(const std::string &name, bool printLabels,
+                     bool onlyPhysicals)
+{
+  FILE *fp = Fopen(name.c_str(), "w");
+  if(!fp) {
+    Msg::Error("Could not open file '%s'", name.c_str());
+    return 0;
+  }
+
+  fprintf(fp, "import gmsh\n");
+  fprintf(fp, "gmsh.initialize()\n");
+
   std::map<double, std::string> meshSizeParameters;
   int cpt = 0;
   for(auto it = firstVertex(); it != lastVertex(); it++) {
@@ -1762,7 +1923,7 @@ int GModel::writeGEO(const std::string &name, bool printLabels,
     if(meshSizeParameters.find(val) == meshSizeParameters.end()) {
       std::ostringstream paramName;
       paramName << "cl__" << ++cpt;
-      fprintf(fp, "%s = %.16g;\n", paramName.str().c_str(), val);
+      fprintf(fp, "%s = %.16g\n", paramName.str().c_str(), val);
       meshSizeParameters.insert(std::make_pair(val, paramName.str()));
     }
   }
@@ -1770,38 +1931,21 @@ int GModel::writeGEO(const std::string &name, bool printLabels,
   for(auto it = firstVertex(); it != lastVertex(); it++) {
     double val = (*it)->prescribedMeshSizeAtVertex();
     if(!onlyPhysicals || !skipVertex(*it))
-      (*it)->writeGEO(fp, meshSizeParameters[val]);
+      (*it)->writePY(fp, meshSizeParameters[val]);
   }
   for(auto it = firstEdge(); it != lastEdge(); it++) {
-    if(!onlyPhysicals || !skipEdge(*it)) (*it)->writeGEO(fp);
+    if(!onlyPhysicals || !skipEdge(*it)) (*it)->writePY(fp);
   }
   for(auto it = firstFace(); it != lastFace(); it++) {
-    if(!onlyPhysicals || !skipFace(*it)) (*it)->writeGEO(fp);
+    if(!onlyPhysicals || !skipFace(*it)) (*it)->writePY(fp);
   }
   for(auto it = firstRegion(); it != lastRegion(); it++) {
-    if(!onlyPhysicals || !skipRegion(*it)) (*it)->writeGEO(fp);
+    if(!onlyPhysicals || !skipRegion(*it)) (*it)->writePY(fp);
   }
 
-  std::map<int, std::string> labels;
-#if defined(HAVE_PARSER)
-  // get "old-style" labels from parser
-  for(auto it = gmsh_yysymbols.begin(); it != gmsh_yysymbols.end(); ++it)
-    for(std::size_t i = 0; i < it->second.value.size(); i++)
-      labels[(int)it->second.value[i]] = it->first;
-#endif
-
-  std::map<int, std::vector<GEntity *> > groups[4];
-  getPhysicalGroups(groups);
-  for(int i = 0; i < 4; i++)
-    std::for_each(
-      groups[i].begin(), groups[i].end(),
-      writePhysicalGroupGEO(fp, i, printLabels, labels, _physicalNames));
-
-#if defined(HAVE_MESH)
-  std::for_each(getFields()->begin(), getFields()->end(), writeFieldGEO(fp));
-  if(getFields()->getBackgroundField() > 0)
-    fprintf(fp, "Background Field = %i;\n", getFields()->getBackgroundField());
-#endif
+  fprintf(fp, "gmsh.model.geo.synchronize()\n");
+  fprintf(fp, "gmsh.fltk.run()\n");
+  fprintf(fp, "gmsh.finalize()\n");
 
   fclose(fp);
   return 1;
