@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2022 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -36,10 +36,10 @@ public:
   virtual void resetMeshAttributes();
 
   // get/set the coordinates of the vertex
-  virtual GPoint point() const = 0;
-  virtual double x() const = 0;
-  virtual double y() const = 0;
-  virtual double z() const = 0;
+  virtual GPoint point() const { return GPoint(); }
+  virtual double x() const { return 0.; }
+  virtual double y() const { return 0.; }
+  virtual double z() const { return 0.; }
   virtual SPoint3 xyz() const { return SPoint3(x(), y(), z()); }
   virtual void setPosition(GPoint &p);
 
@@ -120,9 +120,9 @@ public:
   std::vector<MPoint *> points;
 
   void addPoint(MPoint *p) { points.push_back(p); }
-  void addElement(int type, MElement *e);
-  void removeElement(int type, MElement *e);
-  void removeElements(int type);
+  void addElement(MElement *e);
+  void removeElement(MElement *e, bool del=false);
+  void removeElements(bool del=false);
 
   virtual bool reorder(const int elementType,
                        const std::vector<std::size_t> &ordering);
