@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2022 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -48,10 +48,8 @@ protected:
                    SVector3 *n, int faceIndex = -1);
   void _getFaceRep(MVertex *v0, MVertex *v1, MVertex *v2, double *x, double *y,
                    double *z, SVector3 *n);
-#if defined(HAVE_VISUDEV)
   void _getFaceRepQuad(MVertex *v0, MVertex *v1, MVertex *v2, MVertex *v3,
                        double *x, double *y, double *z, SVector3 *n);
-#endif
 
   static bool _getFaceInfo(const MFace &face, const MFace &other, int &sign,
                            int &rot);
@@ -400,6 +398,12 @@ public:
   virtual double getEigenvaluesMetric(double u, double v, double w,
                                       double values[3]) const;
 
+  virtual double getAngleAtVertex(MVertex *v)
+  {
+    Msg::Warning("Angle at element node not coded for this element type");
+    return 0.;
+  }
+
   // get the point in cartesian coordinates corresponding to the point (u,v,w)
   // in parametric coordinates
   virtual void pnt(double u, double v, double w, SPoint3 &p) const;
@@ -504,7 +508,7 @@ public:
   virtual void getVerticesIdForMSH(std::vector<int> &verts);
 
   // copy element and parent if any, vertexMap contains the new vertices
-  virtual MElement *copy(std::map<int, MVertex *> &vertexMap,
+  virtual MElement *copy(std::map<std::size_t, MVertex *> &vertexMap,
                          std::map<MElement *, MElement *> &newParents,
                          std::map<MElement *, MElement *> &newDomains);
 
